@@ -5,6 +5,7 @@
 
 // Base class for extensions-api registries
 import { action, observable, makeObservable } from "mobx";
+import type { Disposer } from "../../common/utils";
 import { Singleton } from "../../common/utils";
 import type { LensExtension } from "../lens-extension";
 
@@ -21,7 +22,7 @@ export class BaseRegistry<T, I = T> extends Singleton {
   }
 
   @action
-  add(items: T | T[], extension?: LensExtension) {
+  add(items: T | T[], extension?: LensExtension): Disposer {
     const itemArray = [items].flat() as T[];
 
     itemArray.forEach(item => {
@@ -33,7 +34,7 @@ export class BaseRegistry<T, I = T> extends Singleton {
 
   // eslint-disable-next-line unused-imports/no-unused-vars-ts
   protected getRegisteredItem(item: T, extension?: LensExtension): I {
-    return item as any;
+    return item as never;
   }
 
   @action
