@@ -3,17 +3,17 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 import { getInjectable } from "@ogre-tools/injectable";
-import windowManagerInjectable from "../window-manager.injectable";
 import { navigateToUrlInjectionToken } from "../../common/front-end-routing/navigate-to-url-injection-token";
+import navigateInjectable from "../start-main-application/lens-window/navigate.injectable";
 
 const navigateToUrlInjectable = getInjectable({
   id: "navigate-to-url",
 
   instantiate: (di) => {
-    const windowManager = di.inject(windowManagerInjectable);
+    const navigate = di.inject(navigateInjectable);
 
-    return (url) => {
-      windowManager.navigateSync(url);
+    return async (url) => {
+      await navigate(url);
     };
   },
 
