@@ -6,13 +6,10 @@ import "@testing-library/jest-dom/extend-expect";
 import { KubeConfig } from "@kubernetes/client-node";
 import { fireEvent } from "@testing-library/react";
 import type { RenderResult } from "@testing-library/react";
-import mockFs from "mock-fs";
 import * as selectEvent from "react-select-event";
 import type { CreateCluster } from "../../../../common/cluster/create-cluster-injection-token";
 import { createClusterInjectionToken } from "../../../../common/cluster/create-cluster-injection-token";
 import createContextHandlerInjectable from "../../../../main/context-handler/create-context-handler.injectable";
-import type { OpenDeleteClusterDialog } from "../open.injectable";
-import openDeleteClusterDialogInjectable from "../open.injectable";
 import storesAndApisCanBeCreatedInjectable from "../../../stores-apis-can-be-created.injectable";
 import createKubeconfigManagerInjectable from "../../../../main/kubeconfig-manager/create-kubeconfig-manager.injectable";
 import type { ApplicationBuilder } from "../../test-utils/get-application-builder";
@@ -20,22 +17,8 @@ import { getApplicationBuilder } from "../../test-utils/get-application-builder"
 import normalizedPlatformInjectable from "../../../../common/vars/normalized-platform.injectable";
 import kubectlBinaryNameInjectable from "../../../../main/kubectl/binary-name.injectable";
 import kubectlDownloadingNormalizedArchInjectable from "../../../../main/kubectl/normalized-arch.injectable";
-
-jest.mock("electron", () => ({
-  app: {
-    getVersion: () => "99.99.99",
-    getName: () => "lens",
-    setName: jest.fn(),
-    setPath: jest.fn(),
-    getPath: () => "tmp",
-    getLocale: () => "en",
-    setLoginItemSettings: jest.fn(),
-  },
-  ipcMain: {
-    on: jest.fn(),
-    handle: jest.fn(),
-  },
-}));
+import type { OpenDeleteClusterDialog } from "../open.injectable";
+import openDeleteClusterDialogInjectable from "../open.injectable";
 
 const currentClusterServerUrl = "https://localhost";
 const nonCurrentClusterServerUrl = "http://localhost";
@@ -87,65 +70,50 @@ users:
     token: kubeconfig-user-q4lm4:xxxyyyy
 `;
 
-let config: KubeConfig;
-
 describe("<DeleteClusterDialog />", () => {
-  let applicationBuilder: ApplicationBuilder;
-  let createCluster: CreateCluster;
-  let openDeleteClusterDialog: OpenDeleteClusterDialog;
+  let builder: ApplicationBuilder;
 
-  beforeEach(async () => {
-    applicationBuilder = getApplicationBuilder();
+  beforeEach(() => {
+    builder = getApplicationBuilder();
 
-    applicationBuilder.beforeApplicationStart(({ mainDi, rendererDi }) => {
+    builder.beforeApplicationStart((mainDi) => {
       mainDi.override(createContextHandlerInjectable, () => () => undefined as never);
       mainDi.override(createKubeconfigManagerInjectable, () => () => undefined as never);
       mainDi.override(kubectlBinaryNameInjectable, () => "kubectl");
       mainDi.override(kubectlDownloadingNormalizedArchInjectable, () => "amd64");
       mainDi.override(normalizedPlatformInjectable, () => "darwin");
-      rendererDi.override(storesAndApisCanBeCreatedInjectable, () => true);
     });
 
-    mockFs();
-
-    applicationBuilder.beforeRender(({ rendererDi }) => {
-      openDeleteClusterDialog = rendererDi.inject(openDeleteClusterDialogInjectable);
-      createCluster = rendererDi.inject(createClusterInjectionToken);
+    builder.beforeWindowStart((windowDi) => {
+      windowDi.override(storesAndApisCanBeCreatedInjectable, () => true);
     });
   });
 
-  afterEach(() => {
-    mockFs.restore();
-  });
-
   it("shows context switcher when deleting current cluster", async () => {
-    const mockOpts = {
-      "temp-kube-config": multiClusterConfig,
-    };
+    const config = new KubeConfig();
 
-    mockFs(mockOpts);
-
-    config = new KubeConfig();
     config.loadFromString(multiClusterConfig);
 
-    applicationBuilder.beforeRender(({ rendererDi }) => {
-      const createCluster = rendererDi.inject(createClusterInjectionToken);
+    const rendered = await builder.render();
 
-      const cluster = createCluster({
-        id: "some-current-context-cluster",
-        contextName: "some-current-context",
-        preferences: {
-          clusterName: "some-current-context-cluster",
-        },
-        kubeConfigPath: "./temp-kube-config",
-      }, {
-        clusterServerUrl: currentClusterServerUrl,
-      });
+    const windowDi = builder.applicationWindow.only.di;
 
-      openDeleteClusterDialog({ cluster, config });
+    const createCluster = windowDi.inject(createClusterInjectionToken);
+
+    const cluster = createCluster({
+      id: "some-current-context-cluster",
+      contextName: "some-current-context",
+      preferences: {
+        clusterName: "some-current-context-cluster",
+      },
+      kubeConfigPath: "./temp-kube-config",
+    }, {
+      clusterServerUrl: currentClusterServerUrl,
     });
 
-    const rendered = await applicationBuilder.render();
+    const openDeleteClusterDialog = windowDi.inject(openDeleteClusterDialogInjectable);
+
+    openDeleteClusterDialog({ cluster, config });
 
     const { getByText } = rendered;
 
@@ -158,21 +126,23 @@ describe("<DeleteClusterDialog />", () => {
     expect(getByText("some-non-current-context")).toBeInTheDocument();
   });
 
-
   describe("Kubeconfig with different clusters", () => {
     let rendered: RenderResult;
+    let openDeleteClusterDialog: OpenDeleteClusterDialog;
+    let createCluster: CreateCluster;
+    let config: KubeConfig;
 
     beforeEach(async () => {
-      const mockOpts = {
-        "temp-kube-config": multiClusterConfig,
-      };
-
-      mockFs(mockOpts);
-
       config = new KubeConfig();
+
       config.loadFromString(multiClusterConfig);
 
-      rendered = await applicationBuilder.render();
+      rendered = await builder.render();
+
+      const windowDi = builder.applicationWindow.only.di;
+
+      openDeleteClusterDialog = windowDi.inject(openDeleteClusterDialogInjectable);
+      createCluster = windowDi.inject(createClusterInjectionToken);
     });
 
     it("renders w/o errors", () => {
@@ -268,18 +238,21 @@ describe("<DeleteClusterDialog />", () => {
 
   describe("Kubeconfig with single cluster", () => {
     let rendered: RenderResult;
+    let openDeleteClusterDialog: OpenDeleteClusterDialog;
+    let createCluster: CreateCluster;
+    let config: KubeConfig;
 
     beforeEach(async () => {
-      const mockOpts = {
-        "temp-kube-config": singleClusterConfig,
-      };
-
-      mockFs(mockOpts);
-
       config = new KubeConfig();
+
       config.loadFromString(singleClusterConfig);
 
-      rendered = await applicationBuilder.render();
+      rendered = await builder.render();
+
+      const windowDi = builder.applicationWindow.only.di;
+
+      openDeleteClusterDialog = windowDi.inject(openDeleteClusterDialogInjectable);
+      createCluster = windowDi.inject(createClusterInjectionToken);
     });
 
     it("shows warning if no other contexts left", () => {
