@@ -8,17 +8,21 @@ import type { Pod } from "../../../../common/k8s-api/endpoints";
 import logStoreInjectable from "./store.injectable";
 import type { LogTabData } from "./tab-store";
 
+export interface LoadLogs {
+  (
+    tabId: string,
+    pod: IComputedValue<Pod | undefined>,
+    logTabData: IComputedValue<LogTabData | undefined>,
+  ): Promise<void>;
+}
+
 const loadLogsInjectable = getInjectable({
   id: "load-logs",
 
-  instantiate: (di) => {
+  instantiate: (di): LoadLogs => {
     const logStore = di.inject(logStoreInjectable);
 
-    return (
-      tabId: string,
-      pod: IComputedValue<Pod | undefined>,
-      logTabData: IComputedValue<LogTabData>,
-    ): Promise<void> => logStore.load(tabId, pod, logTabData);
+    return (tabId, pod, logTabData) => logStore.load(tabId, pod, logTabData);
   },
 });
 
