@@ -5,8 +5,8 @@
 import { getInjectable } from "@ogre-tools/injectable";
 import extensionLoaderInjectable from "../../../extensions/extension-loader/extension-loader.injectable";
 import { LensProtocolRouterRenderer } from "./lens-protocol-router-renderer";
-import extensionsStoreInjectable
-  from "../../../extensions/extensions-store/extensions-store.injectable";
+import extensionsStoreInjectable from "../../../extensions/extensions-store/extensions-store.injectable";
+import loggerInjectable from "../../../common/logger.injectable";
 
 const lensProtocolRouterRendererInjectable = getInjectable({
   id: "lens-protocol-router-renderer",
@@ -15,6 +15,7 @@ const lensProtocolRouterRendererInjectable = getInjectable({
     new LensProtocolRouterRenderer({
       extensionLoader: di.inject(extensionLoaderInjectable),
       extensionsStore: di.inject(extensionsStoreInjectable),
+      logger: di.inject(loggerInjectable),
     }),
 });
 
